==> nlrx_0.4.1.tar.gz: nlrx/R/sample_data.R <==
#' Wolf Sheep model sample data: simdesign simple
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a simple simulation design.
#' It also contains the model outputs within the simdesign object.
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_simple"
# > [1] "nl_simple"


#' Wolf Sheep model sample data: simdesign distinct
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a distinct simulation design.
#' It also contains the model outputs within the simdesign object.
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_distinct"
# > [1] "nl_distinct"


#' Wolf Sheep model sample data: simdesign ff
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a full-factorial simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_ff"
# > [1] "nl_ff"



#' Wolf Sheep model sample data: simdesign lhs
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a latin hypercube simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_lhs"
# > [1] "nl_lhs"



#' Wolf Sheep model sample data: simdesign sobol
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a sobol simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_sobol"
# > [1] "nl_sobol"



#' Wolf Sheep model sample data: simdesign sobol2007
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a sobol2007 simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_sobol2007"
# > [1] "nl_sobol2007"



#' Wolf Sheep model sample data: simdesign soboljansen
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a soboljansen simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_soboljansen"
# > [1] "nl_soboljansen"



#' Wolf Sheep model sample data: simdesign morris
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a morris simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_morris"
# > [1] "nl_morris"



#' Wolf Sheep model sample data: simdesign eFast
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run an eFast simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_eFast"
# > [1] "nl_eFast"

#' Wolf Sheep model sample data: spatial
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a simple simulation design.
#' For these simulations, spatial agent output has been collected.
#' metrics.turtles was set up to measure turtle coordinates.
#' metrics.patches was set up to measure colors of cells.
#' It also contains the model outputs within the simdesign object.
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_spatial"
# > [1] "nl_spatial"

==> nlrx_0.4.6.tar.gz: nlrx/R/sample_data.R <==
#' Wolf Sheep model sample data: simdesign simple
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a simple simulation design.
#' It also contains the model outputs within the simdesign object.
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_simple"
# > [1] "nl_simple"


#' Wolf Sheep model sample data: simdesign distinct
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a distinct simulation design.
#' It also contains the model outputs within the simdesign object.
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_distinct"
# > [1] "nl_distinct"


#' Wolf Sheep model sample data: simdesign ff
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a full-factorial simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_ff"
# > [1] "nl_ff"



#' Wolf Sheep model sample data: simdesign lhs
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a latin hypercube simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_lhs"
# > [1] "nl_lhs"



#' Wolf Sheep model sample data: simdesign sobol
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a sobol simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_sobol"
# > [1] "nl_sobol"



#' Wolf Sheep model sample data: simdesign sobol2007
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a sobol2007 simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_sobol2007"
# > [1] "nl_sobol2007"



#' Wolf Sheep model sample data: simdesign soboljansen
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a soboljansen simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_soboljansen"
# > [1] "nl_soboljansen"



#' Wolf Sheep model sample data: simdesign morris
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a morris simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_morris"
# > [1] "nl_morris"



#' Wolf Sheep model sample data: simdesign eFast
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run an eFast simulation design.
#' It also contains the model outputs within the simdesign object.
#' Further analysis output can be derived by submitting the dataset to analyze_nl().
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_eFast"
# > [1] "nl_eFast"

#' Wolf Sheep model sample data: spatial
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a simple simulation design.
#' For these simulations, spatial agent output has been collected.
#' metrics.turtles was set up to measure turtle coordinates.
#' metrics.patches was set up to measure colors of cells.
#' It also contains the model outputs within the simdesign object.
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_spatial"
# > [1] "nl_spatial"


#' Wolf Sheep model sample data: gensa
#'
#' The dataset contains a complete nl object.
#' The nl object has been used to setup and run a simulated annealing simulation design.
#'
#'
#' @format nl object with defined experiment, simdesign and model output
"nl_gensa"
# > [1] "nl_gensa"
